==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/digest_bbs_hosyu.php <==
<?php
//======================================================================
// COPYRIGHT(c) 2001 AQUAPALNNETWORKS LTD CO. All rights reserved.
//----------------------------------------------------------------------
// Program Name		: ɽǼ
// File Name		: digest_bbs_hosyu.php
//----------------------------------------------------------------------
// Date             : 2001/03/26
// Author           : AQUAPALNNETWORKS LIMITED COMPANY
//----------------------------------------------------------------------
// Note				: ȷǼɽ
//                  : 
//----------------------------------------------------------------------
// Rev.             : 2000/09/18 Ǻ
//                  : 2001/03/26 ǼĤʤäԶ
//                  : 2002/01/15 jetjob.increquire
//                  : 
//                  : 
//======================================================================

require("jetjob.inc");
require("common_check.inc");		// 
require("common_login.php");		// 


//==============================================================
// Function Name    : Get_MySection
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Get_MySection()
{
	global $JJ_USER_ID;
	
	$db = new DB_Test;
	$query = sprintf("SELECT section_id FROM common_member WHERE member_id = '%s'", $JJ_USER_ID);
	$db->query($query);
	$db->next_record();
	$ret = $db->f("section_id");
	$db->close();
	
	return $ret;
}


//==============================================================
// Function Name    : Print_bbs
//--------------------------------------------------------------
// Note		        : Ǽľ
//                  :
//==============================================================
Function Print_bbs($MODE)
{
	global $JJ_USERNAME;

	print("<table border=\"0\" cellpadding=\"5\" cellspacing=\"0\" width=600>\n");
	print("<TR class=\"color02\"><TD align=\"center\">\n");

	if ($MODE == "UPD"){
		print("ϡ󤫤ͭˤʤޤ\n");
	}else{
		print("<b>ɽǼĤ򤷤ޤ</b>\n");
	}
	print("</TD></TR>\n");
	print("<TR bgcolor=\"white\"><TD align=\"center\">\n");

	$my_section = Get_MySection();

	$db = new DB_Test;

	$bbs_id = "";
	$db->query("SELECT * FROM common_member WHERE login_name = '$JJ_USERNAME'");
	$db->next_record();
	$bbs_id = $db->f("bbs_id");

//	$db->query("SELECT * FROM bbs_control WHERE bbs_type = 0 ORDER BY bbs_id ");
//	$db->query("SELECT * FROM bbs_control ORDER BY bbs_id");
	$query = sprintf("SELECT * FROM bbs_control WHERE bbs_section = '0' OR bbs_section = '%s' ORDER BY bbs_id",
				$my_section);
	$db->query($query);
	$x = 0;
	while ($db->next_record()) {
		$bbs_title[$x] = $db->f("bbs_title");
		$bbs_start[$x] = $db->f("bbs_id");
		$x++;
	}

	print("<form action=\"digest_bbs_hosyu.php?MODE=UPD\" method=\"post\">\n");
	print("<TABLE cellpadding=\"5\" cellspacing=\"5\">\n");
	print("  <TR bgcolor=\"f7f2e8\">\n");
	print("    <TD ALIGN=\"center\" class=\"color01\"><b>Ǽ̾</b></TD>\n");
	print("    <TD>\n");
	print("    <SELECT NAME=bbs_s>");
	for ($x=0; $x<count($bbs_start); $x++){
		if ($bbs_start[$x] == $bbs_id){
			printf("    <OPTION VALUE=\"$bbs_start[$x]\" SELECTED>%s", htmlspecialchars($bbs_title[$x]));
		}else{
			printf("    <OPTION VALUE=\"$bbs_start[$x]\">%s", htmlspecialchars($bbs_title[$x]));
		}
	}
	print("    </SELECT>");
	print("    </TD>\n");
	print("  </TR>\n");
	print("</TABLE>\n");
	print("<input type=\"submit\" value=\"\">\n");
	print("</FORM>\n");

	print("</TD></TR>\n");
	print("</table>\n");

	$db->close();
}


//==============================================================
// Function Name    : Upd_bbs
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Upd_bbs($bbs_id)
{
	global $JJ_USERNAME;

	$db = new DB_Test;
	$SQL = "UPDATE common_member SET bbs_id = '$bbs_id' WHERE login_name = '$JJ_USERNAME'";
	$db->query($SQL);
	$db->close();
}



//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Login_Start(PG_NAME());

include("common_printheader.inc");

if (!isset($MODE)){
	$MODE="";
}
if ($MODE == "UPD" && isset($bbs_s)) {
	Upd_bbs($bbs_s);
}
Print_bbs($MODE);

include("common_printfooter.inc");

?>

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/digest_bbs_hosyu.php <==
<?php
//======================================================================
// COPYRIGHT(c) 2001 AQUAPALNNETWORKS LTD CO. All rights reserved.
//----------------------------------------------------------------------
// Program Name		: ɽǼ
// File Name		: digest_bbs_hosyu.php
//----------------------------------------------------------------------
// Date             : 2001/03/26
// Author           : AQUAPALNNETWORKS LIMITED COMPANY
//----------------------------------------------------------------------
// Note				: ȷǼɽ
//                  : 
//----------------------------------------------------------------------
// Rev.             : 2000/09/18 Ǻ
//                  : 2001/03/26 ǼĤʤäԶ
//                  : 2002/01/15 jetjob.inc.phprequire
//                  : 
//                  : 
//======================================================================

require("jetjob.inc.php");
require("common_check.inc");		// 
require("common_login.php");		// 


//==============================================================
// Function Name    : Get_MySection
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Get_MySection()
{
	global $JJ_USER_ID;
	
	$db = new DB_Test;
	$query = sprintf("SELECT section_id FROM common_member WHERE member_id = '%s'", $JJ_USER_ID);
	$db->query($query);
	$db->next_record();
	$ret = $db->f("section_id");
	$db->close();
	
	return $ret;
}


//==============================================================
// Function Name    : Print_bbs
//--------------------------------------------------------------
// Note		        : Ǽľ
//                  :
//==============================================================
Function Print_bbs($MODE)
{
	global $JJ_USERNAME;

	print("<table border=\"0\" cellpadding=\"5\" cellspacing=\"0\" width=600>\n");
	print("<TR class=\"color02\"><TD align=\"center\">\n");

	if ($MODE == "UPD"){
		print("ϡ󤫤ͭˤʤޤ\n");
	}else{
		print("<b>ɽǼĤ򤷤ޤ</b>\n");
	}
	print("</TD></TR>\n");
	print("<TR bgcolor=\"white\"><TD align=\"center\">\n");

	$my_section = Get_MySection();

	$db = new DB_Test;

	$bbs_id = "";
	$db->query("SELECT * FROM common_member WHERE login_name = '$JJ_USERNAME'");
	$db->next_record();
	$bbs_id = $db->f("bbs_id");

//	$db->query("SELECT * FROM bbs_control WHERE bbs_type = 0 ORDER BY bbs_id ");
//	$db->query("SELECT * FROM bbs_control ORDER BY bbs_id");
	$query = sprintf("SELECT * FROM bbs_control WHERE bbs_section = '0' OR bbs_section = '%s' ORDER BY bbs_id",
				$my_section);
	$db->query($query);
	$x = 0;
	while ($db->next_record()) {
		$bbs_title[$x] = $db->f("bbs_title");
		$bbs_start[$x] = $db->f("bbs_id");
		$x++;
	}

	print("<form action=\"digest_bbs_hosyu.php?MODE=UPD\" method=\"post\">\n");
	print("<TABLE cellpadding=\"5\" cellspacing=\"5\">\n");
	print("  <TR bgcolor=\"f7f2e8\">\n");
	print("    <TD ALIGN=\"center\" class=\"color01\"><b>Ǽ̾</b></TD>\n");
	print("    <TD>\n");
	print("    <SELECT NAME=bbs_s>");
	for ($x=0; $x<count($bbs_start); $x++){
		if ($bbs_start[$x] == $bbs_id){
			printf("    <OPTION VALUE=\"$bbs_start[$x]\" SELECTED>%s", htmlspecialchars($bbs_title[$x]));
		}else{
			printf("    <OPTION VALUE=\"$bbs_start[$x]\">%s", htmlspecialchars($bbs_title[$x]));
		}
	}
	print("    </SELECT>");
	print("    </TD>\n");
	print("  </TR>\n");
	print("</TABLE>\n");
	print("<input type=\"submit\" value=\"\">\n");
	print("</FORM>\n");

	print("</TD></TR>\n");
	print("</table>\n");

	$db->close();
}


//==============================================================
// Function Name    : Upd_bbs
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Upd_bbs($bbs_id)
{
	global $JJ_USERNAME;

	$db = new DB_Test;
	$SQL = "UPDATE common_member SET bbs_id = '$bbs_id' WHERE login_name = '$JJ_USERNAME'";
	$db->query($SQL);
	$db->close();
}



//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Login_Start(PG_NAME());

include("common_printheader.inc");

if (!isset($MODE)){
	$MODE="";
}
if ($MODE == "UPD" && isset($bbs_s)) {
	Upd_bbs($bbs_s);
}
Print_bbs($MODE);

include("common_printfooter.inc");

?>
